Class: annotatable - LinkML Model

# Class: annotatable

mixin for classes that support annotations

URI: linkml:Annotatable

## Mixin for

- Annotation (mixin) - a tag/value pair with the semantics of OWL Annotation
- Element (mixin) - a named element in the model
- PermissibleValue (mixin) - a permissible value, accompanied by intended text and an optional mapping to a concept URI
- UniqueKey (mixin) - a collection of slots whose values uniquely identify an instance of a class

## Referenced by Class

## Attributes

### Own

- annotations 0..*
  - Description: a collection of tag/text tuples with the semantics of OWL Annotation
  - Range: Annotation